@@ -41,7 +41,7 @@ class KcmTreeItem
         * @param module pointer to KCM module
         * @param parent objects parent
         */
-        explicit KcmTreeItem(const KService::Ptr module, KcmTreeItem *parent=0);
+        explicit KcmTreeItem(const KService::Ptr &module, KcmTreeItem *parent=nullptr);
 
         /**
         * KCM Tree Item for InfoKcmModel. Holds information about a KCM
@@ -77,12 +77,12 @@ class KcmTreeItem
         /**
         * Get amount of children
         */
-        int childCount();
+        int childCount() const;
 
         /**
         * Get parent of current tree item
         */
-        KcmTreeItem *parent();
+        KcmTreeItem *parent() const;
 
         /**
         * Get index of tree item
@@ -93,7 +93,7 @@ class KcmTreeItem
         * Get amount of columns that tree item contains.
         * Hardcoded to 1
         */
-        int columnCount();
+        int columnCount() const;
 
         /**
         * Get row of tree item
@@ -130,7 +130,7 @@ class KcmTreeItem
         /**
         * Get tree items KCM's weight
         */
-        virtual int weight();
+        virtual int weight() const;
 
         /**
         * Get icon tied to KCM
